@@ -39,6 +39,7 @@
 // Copyright (C) 2017 Jean Ghali <jghali@libertysurf.fr>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
+// Copyright (C) 2019 Christian Persch <chpe@src.gnome.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -401,8 +402,6 @@ GlobalParams::GlobalParams(const char *customPopplerDataDir)
   textEncoding = new GooString("UTF-8");
 #if defined(_WIN32)
   textEOL = eolDOS;
-#elif defined(MACOS)
-  textEOL = eolMac;
 #else
   textEOL = eolUnix;
 #endif
@@ -1064,7 +1063,7 @@ void GlobalParams::setupBaseFonts(char *dir) {
     fileName = nullptr;
     if (dir) {
       fileName = appendToPath(new GooString(dir), displayFontTab[i].t1FileName);
-      if ((f = fopen(fileName->c_str(), "rb"))) {
+      if ((f = openFile(fileName->c_str(), "rb"))) {
 	      fclose(f);
       } else {
 	      delete fileName;
@@ -1074,7 +1073,7 @@ void GlobalParams::setupBaseFonts(char *dir) {
     for (j = 0; !fileName && displayFontDirs[j]; ++j) {
       fileName = appendToPath(new GooString(displayFontDirs[j]),
 			      displayFontTab[i].t1FileName);
-      if ((f = fopen(fileName->c_str(), "rb"))) {
+      if ((f = openFile(fileName->c_str(), "rb"))) {
 	      fclose(f);
       } else {
 	      delete fileName;
