@@ -35,7 +35,6 @@
 #define HTMLOUTPUTDEV_H
 
 #include <stdio.h>
-#include "goo/gtypes.h"
 #include "goo/GooList.h"
 #include "GfxFont.h"
 #include "OutputDev.h"
@@ -139,7 +138,7 @@ public:
   void addChar(GfxState *state, double x, double y,
 	       double dx, double dy, 
 		double ox, double oy, 
-		Unicode *u, int uLen); //Guchar c);
+		Unicode *u, int uLen); //unsigned char c);
 
   void updateFont(GfxState *state);
 
@@ -152,7 +151,7 @@ public:
   // Find a string.  If <top> is true, starts looking at top of page;
   // otherwise starts looking at <xMin>,<yMin>.  If <bottom> is true,
   // stops looking at bottom of page; otherwise stops looking at
-  // <xMax>,<yMax>.  If found, sets the text bounding rectange and
+  // <xMax>,<yMax>.  If found, sets the text bounding rectangle and
   // returns true; otherwise returns false.
   
 
